==> haskell-posix-paths-0.3.0.0-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-8dxSPdabRjZ58euR0sCvqH
key:                  posix-paths-0.3.0.0-8dxSPdabRjZ58euR0sCvqH
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  6c0b605cda5d2f953ad3cdd22445930c
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-8dxSPdabRjZ58euR0sCvqH
depends:
    base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
    unliftio-0.2.25.1-3Yhh17ZiDqL8wBy06T4Fv

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-posix-paths-0.3.0.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-posix-paths.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 posix-paths
version:              0.3.0.0
visibility:           public
id:                   posix-paths-0.3.0.0-9ze8lv41fo5fYLP9TLQaS
key:                  posix-paths-0.3.0.0-9ze8lv41fo5fYLP9TLQaS
license:              BSD-3-Clause
maintainer:           jwlato@gmail.com
synopsis:             POSIX filepath/directory functionality
description:
    This package gives access to certain POSIX-based Filepath/Directory
    services.

    The package is not supported under Windows (except under Cygwin).

category:             System
abi:                  94aa3b48f98ec899bbf1107c529a87c6
exposed:              True
exposed-modules:
    System.Posix.Directory.Foreign System.Posix.Directory.Traversals
    System.Posix.FilePath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/posix-paths-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-posix-paths
hs-libraries:         HSposix-paths-0.3.0.0-9ze8lv41fo5fYLP9TLQaS
depends:
    base-4.17.2.1 bytestring-0.11.5.3 unix-2.7.3
    unliftio-0.2.25.1-CgePo7ngrPgLZdb5MfeeLl

haddock-interfaces:   /usr/share/doc/haskell-posix-paths/html/posix-paths.haddock
haddock-html:         /usr/share/doc/haskell-posix-paths/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
